# Python Link Operations with `plinko`

https://packaging.python.org/en/latest/tutorials/packaging-projects/
https://python-packaging-tutorial.readthedocs.io/en/latest/setup_py.html
http://pythonchb.github.io/PythonTopics/where_to_put_tests.html